@@ -119,7 +119,7 @@
 #'   Interpreting Confounder and Modifier Coefficients. American Journal of
 #'   Epidemiology, 177(4), 292–298. \doi{10.1093/aje/kws412}
 #'
-#' @examplesIf require("ggdag", quietly = TRUE) && require("dagitty", quietly = TRUE) && require("see", quietly = TRUE)
+#' @examplesIf all(insight::check_if_installed(c("ggdag", "dagitty", "see"), quietly = TRUE))
 #' # no adjustment needed
 #' check_dag(
 #'   y ~ x + b,
@@ -215,14 +215,17 @@ check_dag <- function(...,
                       exposure = NULL,
                       adjusted = NULL,
                       latent = NULL,
-                      effect = c("all", "total", "direct"),
+                      effect = "all",
                       coords = NULL) {
   insight::check_if_installed(
     c("ggdag", "dagitty"),
     reason = "to check correct adjustments for identifying causal effects."
   )
 
-  effect <- match.arg(effect)
+  effect <- insight::validate_argument(
+    effect,
+    c("all", "total", "direct")
+  )
 
   # retrieve formulas
   formulas <- list(...)
