@@ -9,7 +9,7 @@
 #' @param ... Not used.
 #'
 #' @examples
-#' V <- wilcox.test(mtcars$mpg)
+#' V <- suppressWarnings(wilcox.test(mtcars$mpg))
 #' check_symmetry(V)
 #'
 #' @export
@@ -19,7 +19,7 @@ check_symmetry <- function(x, ...) {
 
 #' @export
 check_symmetry.numeric <- function(x, ...) {
-  x <- stats::na.omit(x)
+  x <- x[!is.na(x)]
 
   m <- mean(x)
   a <- stats::median(x)
@@ -44,4 +44,4 @@ print.check_symmetry <- function(x, ...) {
     insight::print_color(sprintf("OK: Data appears symmetrical (%s).\n", pstring), "green")
   }
   return(invisible(x))
-}
\ No newline at end of file
+}
