@@ -203,12 +203,11 @@ compare_performance <- function(..., metrics = "all", rank = FALSE, estimator =
 }
 
 
-
 # methods ----------------------------
 
 #' @export
 print.compare_performance <- function(x, digits = 3, layout = "horizontal", ...) {
-  layout <- match.arg(layout, choices = c("horizontal", "vertical"))
+  layout <- insight::validate_argument(layout, c("horizontal", "vertical"))
   table_caption <- c("# Comparison of Model Performance Indices", "blue")
   formatted_table <- format(x = x, digits = digits, format = "text", ...)
 
@@ -237,7 +236,6 @@ plot.compare_performance <- function(x, ...) {
 }
 
 
-
 # utilities ------------------------------
 
 .rank_performance_indices <- function(x, verbose) {
