@@ -1,28 +1,29 @@
 #' @title Difficulty of Questionnaire Items
 #' @name item_difficulty
 #'
-#' @description Compute various measures of internal consistencies
-#'    for tests or item-scales of questionnaires.
+#' @description Compute various measures of internal consistencies for tests or
+#' item-scales of questionnaires.
 #'
-#' @param x Depending on the function, `x` may be a `matrix` as
-#'    returned by the `cor()`-function, or a data frame
-#'    with items (e.g. from a test or questionnaire).
+#' @param x Depending on the function, `x` may be a `matrix` as returned by the
+#' `cor()`-function, or a data frame with items (e.g. from a test or
+#' questionnaire).
 #' @param maximum_value Numeric value, indicating the maximum value of an item.
-#'   If `NULL` (default), the maximum is taken from the maximum value of all
-#'   columns in `x` (assuming that the maximum value at least appears once in
-#'   the data). If `NA`, each item's maximum value is taken as maximum. If the
-#'   required maximum value is not present in the data, specify the theoreritcal
-#'   maximum using `maximum_value`.
+#' If `NULL` (default), the maximum is taken from the maximum value of all
+#' columns in `x` (assuming that the maximum value at least appears once in the
+#' data). If `NA`, each item's maximum value is taken as maximum. If the
+#' required maximum value is not present in the data, specify the theoreritcal
+#' maximum using `maximum_value`.
+#'
 #' @return A data frame with three columns: The name(s) of the item(s), the item
-#'      difficulties for each item, and the ideal item difficulty.
+#' difficulties for each item, and the ideal item difficulty.
 #'
 #' @details _Item difficutly_ of an item is defined as the quotient of the sum
-#'   actually achieved for this item of all and the maximum achievable score.
-#'   This function calculates the item difficulty, which should range between
-#'   0.2 and 0.8. Lower values are a signal for more difficult items, while
-#'   higher values close to one are a sign for easier items. The ideal value
-#'   for item difficulty is `p + (1 - p) / 2`, where `p = 1 / max(x)`. In most
-#'   cases, the ideal item difficulty lies between 0.5 and 0.8.
+#' actually achieved for this item of all and the maximum achievable score. This
+#' function calculates the item difficulty, which should range between 0.2 and
+#' 0.8. Lower values are a signal for more difficult items, while higher values
+#' close to one are a sign for easier items. The ideal value for item difficulty
+#' is `p + (1 - p) / 2`, where `p = 1 / max(x)`. In most cases, the ideal item
+#' difficulty lies between 0.5 and 0.8.
 #'
 #' @references
 #' - Bortz, J., and Döring, N. (2006). Quantitative Methoden der Datenerhebung.
@@ -82,7 +83,6 @@ item_difficulty <- function(x, maximum_value = NULL) {
 }
 
 
-
 # methods --------------------------------------
 
 #' @export
@@ -91,3 +91,17 @@ print.item_difficulty <- function(x, ...) {
   cat(insight::export_table(out, caption = c("Item Difficulty", "blue"), ...))
   invisible(x)
 }
+
+
+#' @export
+print_md.item_difficulty <- function(x, ...) {
+  out <- insight::format_table(x, ...)
+  insight::export_table(out, caption = "Item Difficulty", format = "markdown", ...)
+}
+
+
+#' @export
+print_html.item_difficulty <- function(x, ...) {
+  out <- insight::format_table(x, ...)
+  insight::export_table(out, caption = "Item Difficulty", format = "html", ...)
+}
