@@ -12,22 +12,21 @@
 #'   compute the accuracy values.
 #' @param n Number of bootstrap-samples.
 #' @param verbose Toggle warnings.
+#' @inheritParams performance_pcp
 #'
-#' @return A list with three values: The `Accuracy` of the model
-#'   predictions, i.e. the proportion of accurately predicted values from the
-#'   model, its standard error, `SE`, and the `Method` used to compute
-#'   the accuracy.
+#' @return A list with three values: The `Accuracy` of the model predictions,
+#' i.e. the proportion of accurately predicted values from the model, its
+#' standard error, `SE`, and the `Method` used to compute the accuracy.
 #'
 #' @details For linear models, the accuracy is the correlation coefficient
-#'    between the actual and the predicted value of the outcome. For
-#'    logistic regression models, the accuracy corresponds to the
-#'    AUC-value, calculated with the `bayestestR::auc()`-function.
-#'    \cr \cr
-#'    The accuracy is the mean value of multiple correlation resp.
-#'    AUC-values, which are either computed with cross-validation
-#'    or non-parametric bootstrapping (see argument `method`).
-#'    The standard error is the standard deviation of the computed
-#'    correlation resp. AUC-values.
+#' between the actual and the predicted value of the outcome. For logistic
+#' regression models, the accuracy corresponds to the AUC-value, calculated with
+#' the [`bayestestR::auc()`]-function.
+#'
+#' The accuracy is the mean value of multiple correlation resp. AUC-values,
+#' which are either computed with cross-validation or non-parametric
+#' bootstrapping (see argument `method`). The standard error is the standard
+#' deviation of the computed correlation resp. AUC-values.
 #'
 #' @examples
 #' model <- lm(mpg ~ wt + cyl, data = mtcars)
@@ -37,11 +36,12 @@
 #' performance_accuracy(model)
 #' @export
 performance_accuracy <- function(model,
-                                 method = c("cv", "boot"),
+                                 method = "cv",
                                  k = 5,
                                  n = 1000,
+                                 ci = 0.95,
                                  verbose = TRUE) {
-  method <- match.arg(method)
+  method <- insight::validate_argument(method, c("cv", "boot"))
 
   # get formula from model fit
   formula <- stats::formula(model)
@@ -186,6 +186,9 @@ performance_accuracy <- function(model,
     list(
       Accuracy = mean(accuracy, na.rm = TRUE),
       SE = stats::sd(accuracy, na.rm = TRUE),
+      CI = ci,
+      CI_low = as.vector(stats::quantile(accuracy, 1 - ((1 + ci) / 2), na.rm = TRUE)),
+      CI_high = as.vector(stats::quantile(accuracy, (1 + ci) / 2, na.rm = TRUE)),
       Method = measure
     )
   )
@@ -199,6 +202,9 @@ as.data.frame.performance_accuracy <- function(x, row.names = NULL, ...) {
   data.frame(
     Accuracy = x$Accuracy,
     SE = x$SE,
+    CI = x$CI,
+    CI_low = x$CI_low,
+    CI_high = x$CI_high,
     Method = x$Method,
     stringsAsFactors = FALSE,
     row.names = row.names,
@@ -213,15 +219,19 @@ print.performance_accuracy <- function(x, ...) {
   insight::print_color("# Accuracy of Model Predictions\n\n", "blue")
 
   # statistics
-  cat(sprintf("Accuracy: %.2f%%\n", 100 * x$Accuracy))
-  cat(sprintf("      SE: %.2f%%-points\n", 100 * x$SE))
-  cat(sprintf("  Method: %s\n", x$Method))
+  cat(sprintf(
+    "Accuracy (%i%% CI): %.2f%% [%.2f%%, %.2f%%]\nMethod: %s\n",
+    round(100 * x$CI),
+    100 * x$Accuracy,
+    100 * x$CI_low,
+    100 * x$CI_high,
+    x$Method
+  ))
 
   invisible(x)
 }
 
 
-
 # utilities ------------------------
 
 .crossv_kfold <- function(model_data, k = 5) {
