@@ -8,9 +8,9 @@
 #' @return The R2 value.
 #'
 #' @references
-#' \itemize{
-#'   \item McKelvey, R., Zavoina, W. (1975), "A Statistical Model for the Analysis of Ordinal Level Dependent Variables", Journal of Mathematical Sociology 4, S. 103–120.
-#' }
+#' McKelvey, R., Zavoina, W. (1975), "A Statistical Model for the Analysis of
+#' Ordinal Level Dependent Variables", Journal of Mathematical Sociology 4, S.
+#' 103–120.
 #'
 #' @details McKelvey and Zavoinas R2 is based on the explained variance,
 #'   where the variance of the predicted response is divided by the sum
@@ -21,7 +21,6 @@
 #'   the *distribution-specific variance* as described in
 #'   `?insight::get_variance`.
 #'
-#'
 #' @examples
 #' ## Dobson (1990) Page 93: Randomized Controlled Trial:
 #' counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12) #
@@ -46,7 +45,7 @@ r2_mckelvey.default <- function(model) {
   faminfo <- insight::model_info(model)
   n <- insight::n_obs(model, disaggregate = TRUE)
 
-  if (faminfo$is_binomial | faminfo$is_ordinal | faminfo$is_multinomial) {
+  if (faminfo$is_binomial || faminfo$is_ordinal || faminfo$is_multinomial) {
     dist.variance <- switch(faminfo$link_function,
       probit = 1,
       logit = pi^2 / 3,
@@ -75,13 +74,8 @@ r2_mckelvey.default <- function(model) {
 }
 
 
-.null_model <- function(model) {
-  stats::update(model, ~1)
-}
-
-
 .get_poisson_variance <- function(model) {
-  mu <- exp(stats::coef(.null_model(model)))
+  mu <- exp(stats::coef(insight::null_model(model)))
   if (is.na(mu)) {
     return(0)
   }
