@@ -230,7 +230,6 @@ test_performance <- function(..., reference = 1, verbose = TRUE) {
 }
 
 
-
 # default --------------------------------
 
 #' @export
@@ -253,7 +252,6 @@ test_performance.default <- function(..., reference = 1, include_formula = FALSE
 }
 
 
-
 # methods ------------------------------
 
 #' @export
@@ -307,15 +305,15 @@ print_html.test_performance <- function(x, digits = 2, ...) {
 
 #' @export
 display.test_performance <- function(object, format = "markdown", digits = 2, ...) {
-  if (format == "markdown") {
-    print_md(x = object, digits = digits, ...)
-  } else {
+  format <- insight::validate_argument(format, c("markdown", "md", "html"))
+  if (format == "html") {
     print_html(x = object, digits = digits, ...)
+  } else {
+    print_md(x = object, digits = digits, ...)
   }
 }
 
 
-
 # other classes -----------------------------------
 
 #' @export
@@ -406,7 +404,6 @@ test_performance.ListNonNestedRegressions <- function(objects,
 }
 
 
-
 # TESTS IMPLEMENTED IN OTHER PACKAGES
 
 # # Non-nested
@@ -416,7 +413,6 @@ test_performance.ListNonNestedRegressions <- function(objects,
 # nonnest2::icci(m2, m3)
 
 
-
 # Helpers -----------------------------------------------------------------
 
 
@@ -432,7 +428,6 @@ test_performance.ListNonNestedRegressions <- function(objects,
 }
 
 
-
 .test_performance_checks <- function(objects, multiple = TRUE, same_response = TRUE, verbose = TRUE) {
   # TODO: we could actually generate a baseline model 'y ~ 1' whenever a single model is passed
   if (multiple && insight::is_model(objects)) {
@@ -472,7 +467,6 @@ test_performance.ListNonNestedRegressions <- function(objects,
 }
 
 
-
 .check_objectnames <- function(objects, dot_names) {
   # Replace with names from the global environment, if these are not yet properly set
   object_names <- insight::compact_character(names(objects))
